@@ -533,7 +533,7 @@ class HDUList(list, _Verify):
                 continue
 
     @_with_extensions
-    def flush(self, output_verify='exception', verbose=False,
+    def flush(self, output_verify='fix', verbose=False,
               classExtensions={}):
         """
         Force a write of the `HDUList` back to the file (for append and
@@ -994,6 +994,11 @@ class HDUList(list, _Verify):
 
             # determine if any of the HDU is resized
             for hdu in self:
+                # A shortcut to let an HDU tell us for itself whether or not it
+                # will be resized
+                if hasattr(hdu, '_resize') and hdu._resize:
+                    self._resize = True
+                    break
 
                 # Header:
                 # Add 1 to .ascard to include the END card
