@@ -322,9 +322,9 @@ class TestTableFunctions(PyfitsTestCase):
         # Double check that the array is converted to the correct byte-order
         # for FITS (big-endian).
         tbhdu.writeto(self.temp('testendian.fits'), clobber=True)
-        hdul = pyfits.open(self.temp('testendian.fits'))
-        assert_true((hdul[1].data['a'] == a2).all())
-        assert_true((hdul[1].data['b'] == a2).all())
+        with pyfits.open(self.temp('testendian.fits')) as hdul:
+            assert_true((hdul[1].data['a'] == a2).all())
+            assert_true((hdul[1].data['b'] == a2).all())
 
     def test_recarray_to_bintablehdu(self):
         bright=np.rec.array([(1,'Serius',-1.45,'A1V'),\
@@ -1689,6 +1689,24 @@ class TestTableFunctions(PyfitsTestCase):
         assert_true((s2 == s3).all())
         assert_true((s3 == s4).all())
 
+    def test_array_slicing_readonly(self):
+        """
+        Like test_array_slicing but with the file opened in 'readonly' mode.
+        Regression test for a crash when slicing readonly memmap'd tables.
+        """
+
+        f = pyfits.open(self.data('table.fits'), mode='readonly')
+        data = f[1].data
+        s1 = data[data['target'] == 'NGC1001']
+        s2 = data[np.where(data['target'] == 'NGC1001')]
+        s3 = data[[0]]
+        s4 = data[:1]
+        for s in [s1, s2, s3, s4]:
+            assert_true(isinstance(s, pyfits.FITS_rec))
+        assert_true((s1 == s2).all())
+        assert_true((s2 == s3).all())
+        assert_true((s3 == s4).all())
+
     def test_attribute_field_shadowing(self):
         """
         Regression test for #86.
